==> 0.1.44.tar.gz: android/src/main/java/com/outerboxcloud/outerboxtsc/OuterboxtscPlugin.java <==
package com.outerboxcloud.outerboxtsc;

import android.os.Environment;
import android.os.StrictMode;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.example.tscdll.TscWifiActivity;

/** OuterboxtscPlugin */
public class OuterboxtscPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  TscWifiActivity tscEthernetRunner = new TscWifiActivity();


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
//    StrictMode.setThreadPolicy(new StrictMode.ThreadPolicy.Builder()
//            .detectDiskReads()
//            .detectDiskWrites()
//            .detectNetwork()   // or .detectAll() for all detectable problems
//            .penaltyLog()
//            .build());
//    StrictMode.setVmPolicy(new StrictMode.VmPolicy.Builder()
//            .detectLeakedSqlLiteObjects()
//            .detectLeakedClosableObjects()
//            .penaltyLog()
//            .penaltyDeath()
//            .build());
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "outerboxtsc");
    channel.setMethodCallHandler(new OuterboxtscPlugin());
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "outerboxtsc");
    channel.setMethodCallHandler(new OuterboxtscPlugin());
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

    if (call.method.equals("sticker")) {
      String ipAddress = call.argument("ipAddress");
      String customer = call.argument("customer");
      String product = call.argument("product");
      String productSub = call.argument("productSub");
      String number = call.argument("number");
      String currentDate = call.argument("currentDate");
      String currentTime = call.argument("currentTime");
      String variance1 = call.argument("variance1");
      String variance2 = call.argument("variance2");
      String variance3 = call.argument("variance3");
      String variance4 = call.argument("variance4");
      String option1 = call.argument("option1");
      String option2 = call.argument("option2");
      String data = call.argument("data");

      String[] arrOfStr = data.split("_");

      // System.out.println(Environment.getExternalStorageDirectory().getPath()); /storage/emulated/0
      tscEthernetRunner.openport(ipAddress,9100, 40);
      tscEthernetRunner.setup(58, 41, 4, 1, 0, 3, 0);
      tscEthernetRunner.clearbuffer();
      // tscEthernetRunner.downloadttf("OpenSans-Regular.ttf");
      for (String a : arrOfStr) {
        String[] listValue = a.split("&");
        // System.out.println("1st -> " + listValue.length);
          if(listValue[0].length() == 4){
            tscEthernetRunner.printerfont(200, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 5){
            tscEthernetRunner.printerfont(180, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 6){
            tscEthernetRunner.printerfont(140, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 7){
            tscEthernetRunner.printerfont(100, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() > 7){
            tscEthernetRunner.printerfont(80, 20, "4", 0, 1, 1, listValue[0]);
          }
           // product
          if(listValue[1].length() > 14){
            tscEthernetRunner.printerfont(40, 55, "3", 0, 1, 1, listValue[1]);
          } else {
            tscEthernetRunner.printerfont(150, 55, "3", 0, 1, 1, listValue[1]);
          }
           // productSub
          tscEthernetRunner.bar("14", "100", "500", "3");
          tscEthernetRunner.bar("14", "220", "500", "3");

          if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && !listValue[6].equals(" ")  && !listValue[7].equals(" ") ){
            tscEthernetRunner.printerfont(14, 125, "1", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "1", 0, 1, 1, listValue[3] + " " + listValue[6]); // option 2
            tscEthernetRunner.printerfont(14, 175, "1", 0, 1, 1, listValue[4] + " " + listValue[7]); // variance 1

            // tscEthernetRunner.printerfont(160, 125, "1", 0, 1, 1, listValue[5]); // variance 2
            // tscEthernetRunner.printerfont(160, 150, "1", 0, 1, 1, listValue[6]); // variance 3
            // tscEthernetRunner.printerfont(160, 165, "1", 0, 1, 1, listValue[7]); // variance 4
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && !listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "1", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "1", 0, 1, 1, listValue[3] + " " + listValue[6]); // option 2
            tscEthernetRunner.printerfont(14, 175, "1", 0, 1, 1, listValue[4]); // variance 1

            // tscEthernetRunner.printerfont(140, 125, "1", 0, 1, 1, listValue[5]); // variance 2
            // tscEthernetRunner.printerfont(140, 150, "1", 0, 1, 1, listValue[6]); // variance 3
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
            tscEthernetRunner.printerfont(14, 175, "2", 0, 1, 1, listValue[4]); // variance 1

            // tscEthernetRunner.printerfont(140, 125, "2", 0, 1, 1, listValue[5]); // variance 2

          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
            tscEthernetRunner.printerfont(14, 175, "2", 0, 1, 1, listValue[4]); // variance 1
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
          } else if(!listValue[2].equals(" ") && listValue[3].equals(" ") && listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "3", 0, 1, 1, listValue[2]); // option 1
          }


          tscEthernetRunner.printerfont(275, 250, "3", 0, 1, 1, listValue[8]); // current date
          tscEthernetRunner.printerfont(328, 280, "3", 0, 1, 1, listValue[9]); // current time

          tscEthernetRunner.printerfont(14, 250, "3", 0, 1, 1, listValue[10]); // customer
          tscEthernetRunner.printerfont(14, 280, "3", 0, 1, 1, "Item: " + listValue[11] + " of " + listValue[12]); // number and page total
          tscEthernetRunner.printlabel(1, 1);
          tscEthernetRunner.clearbuffer();
      }

      tscEthernetRunner.closeport();

      result.success("Success Printing");
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    //channel.setMethodCallHandler(null);

  }
}

==> 0.1.45.tar.gz: android/src/main/java/com/outerboxcloud/outerboxtsc/OuterboxtscPlugin.java <==
package com.outerboxcloud.outerboxtsc;

import android.os.Environment;
import android.os.StrictMode;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.example.tscdll.TscWifiActivity;

/** OuterboxtscPlugin */
public class OuterboxtscPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  TscWifiActivity tscEthernetRunner = new TscWifiActivity();


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
//    StrictMode.setThreadPolicy(new StrictMode.ThreadPolicy.Builder()
//            .detectDiskReads()
//            .detectDiskWrites()
//            .detectNetwork()   // or .detectAll() for all detectable problems
//            .penaltyLog()
//            .build());
//    StrictMode.setVmPolicy(new StrictMode.VmPolicy.Builder()
//            .detectLeakedSqlLiteObjects()
//            .detectLeakedClosableObjects()
//            .penaltyLog()
//            .penaltyDeath()
//            .build());
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "outerboxtsc");
    channel.setMethodCallHandler(new OuterboxtscPlugin());
  }

  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "outerboxtsc");
    channel.setMethodCallHandler(new OuterboxtscPlugin());
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

    if (call.method.equals("sticker")) {
      String ipAddress = call.argument("ipAddress");
      String customer = call.argument("customer");
      String product = call.argument("product");
      String productSub = call.argument("productSub");
      String number = call.argument("number");
      String currentDate = call.argument("currentDate");
      String currentTime = call.argument("currentTime");
      String variance1 = call.argument("variance1");
      String variance2 = call.argument("variance2");
      String variance3 = call.argument("variance3");
      String variance4 = call.argument("variance4");
      String option1 = call.argument("option1");
      String option2 = call.argument("option2");
      String data = call.argument("data");

      String[] arrOfStr = data.split("_");

      // System.out.println(Environment.getExternalStorageDirectory().getPath()); /storage/emulated/0
      tscEthernetRunner.openport(ipAddress,9100, 40);
      tscEthernetRunner.setup(58, 41, 4, 1, 0, 3, 0);
      tscEthernetRunner.clearbuffer();
      // tscEthernetRunner.downloadttf("OpenSans-Regular.ttf");
      for (String a : arrOfStr) {
        String[] listValue = a.split("&");
        // System.out.println("1st -> " + listValue.length);
          if(listValue[0].length() == 4){
            tscEthernetRunner.printerfont(200, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 5){
            tscEthernetRunner.printerfont(180, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 6){
            tscEthernetRunner.printerfont(140, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() == 7){
            tscEthernetRunner.printerfont(100, 20, "4", 0, 1, 1, listValue[0]);
          } else if(listValue[0].length() > 7){
            tscEthernetRunner.printerfont(80, 20, "4", 0, 1, 1, listValue[0]);
          }
           // product
          if(listValue[1].length() > 14){
            tscEthernetRunner.printerfont(40, 55, "3", 0, 1, 1, listValue[1]);
          } else {
            tscEthernetRunner.printerfont(150, 55, "3", 0, 1, 1, listValue[1]);
          }
           // productSub
          tscEthernetRunner.bar("14", "100", "500", "3");
          tscEthernetRunner.bar("14", "220", "500", "3");

          if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && !listValue[6].equals(" ")  && !listValue[7].equals(" ") ){
            tscEthernetRunner.printerfont(14, 125, "1", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "1", 0, 1, 1, listValue[3] + " " + listValue[6]); // option 2
            tscEthernetRunner.printerfont(14, 175, "1", 0, 1, 1, listValue[4] + " " + listValue[7]); // variance 1

            // tscEthernetRunner.printerfont(160, 125, "1", 0, 1, 1, listValue[5]); // variance 2
            // tscEthernetRunner.printerfont(160, 150, "1", 0, 1, 1, listValue[6]); // variance 3
            // tscEthernetRunner.printerfont(160, 165, "1", 0, 1, 1, listValue[7]); // variance 4
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && !listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "1", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "1", 0, 1, 1, listValue[3] + " " + listValue[6]); // option 2
            tscEthernetRunner.printerfont(14, 175, "1", 0, 1, 1, listValue[4]); // variance 1

            // tscEthernetRunner.printerfont(140, 125, "1", 0, 1, 1, listValue[5]); // variance 2
            // tscEthernetRunner.printerfont(140, 150, "1", 0, 1, 1, listValue[6]); // variance 3
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && !listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2] + " " + listValue[5]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
            tscEthernetRunner.printerfont(14, 175, "2", 0, 1, 1, listValue[4]); // variance 1

            // tscEthernetRunner.printerfont(140, 125, "2", 0, 1, 1, listValue[5]); // variance 2

          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && !listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
            tscEthernetRunner.printerfont(14, 175, "2", 0, 1, 1, listValue[4]); // variance 1
          } else if(!listValue[2].equals(" ") && !listValue[3].equals(" ") && listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "2", 0, 1, 1, listValue[2]); // option 1
            tscEthernetRunner.printerfont(14, 150, "2", 0, 1, 1, listValue[3]); // option 2
          } else if(!listValue[2].equals(" ") && listValue[3].equals(" ") && listValue[4].equals(" ") && listValue[5].equals(" ") && listValue[6].equals(" ")  && listValue[7].equals(" ")){
            tscEthernetRunner.printerfont(14, 125, "3", 0, 1, 1, listValue[2]); // option 1
          }


          // tscEthernetRunner.printerfont(275, 250, "3", 0, 1, 1, listValue[8]); // current date
          // tscEthernetRunner.printerfont(328, 280, "3", 0, 1, 1, listValue[9]); // current time
          tscEthernetRunner.printerfont(14, 250, "3", 0, 1, 1, listValue[8] + " " + listValue[9]);
          // tscEthernetRunner.printerfont(14, 250, "3", 0, 1, 1, listValue[10]); // customer
          tscEthernetRunner.printerfont(14, 280, "3", 0, 1, 1, "Item: " + listValue[11] + " of " + listValue[12] + " - " + listValue[10]); // number and page total
          tscEthernetRunner.printlabel(1, 1);
          tscEthernetRunner.clearbuffer();
      }

      tscEthernetRunner.closeport();

      result.success("Success Printing");
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    //channel.setMethodCallHandler(null);

  }
}
